package cn.com.ty.lift.business.contract.service;

import cn.com.ty.lift.business.common.BeanUtils;
import cn.com.ty.lift.business.contract.dao.entity.Contracts;
import cn.com.ty.lift.business.contract.dao.entity.ContractsHistory;
import cn.com.ty.lift.business.contract.dao.entity.model.request.ContractRequest;
import cn.com.ty.lift.business.contract.dao.mapper.ContractsHistoryMapper;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.time.LocalDateTime;
import java.util.Map;

/**
 * @author bieao
 * @date 2020/1/8
 * @description 合同历史记录业务层
 */
@Service
public class ContractHistoryService extends ServiceImpl<ContractsHistoryMapper, ContractsHistory> {

    @Resource
    private BeanUtils utils;

    /**
     * @param request 合同编号
     * @return IPage<ContractsHistory> 合同历史记录
     * @description 根据合同编号查询合同历史记录
     * @date 2020/1/8 11:37 上午
     */
    public IPage<ContractsHistory> list(ContractRequest request) {
        QueryWrapper<ContractsHistory> queryWrapper = new QueryWrapper<>();
        LambdaQueryWrapper<ContractsHistory> lambdaQueryWrapper = queryWrapper.lambda();
        lambdaQueryWrapper.eq(ContractsHistory::getContractsId, request.getContractId());
        return page(request.getPage(), lambdaQueryWrapper);
    }

    /**
     * @param oldEntry 原有大修项目
     * @param newEntry 修改后的大修项目
     * @return
     * @description 保存大修项目操作记录
     * @date 2020/4/28 9:52 上午
     */
    public void saveOperaHistory(Contracts oldEntry, Contracts newEntry) throws NoSuchFieldException {
        Map<String, String> resultMap = utils.compareAttribute(oldEntry, newEntry);
        ContractsHistory contractsHistory = new ContractsHistory();
        contractsHistory.setContractsId(oldEntry.getId());
        contractsHistory.setCode(oldEntry.getCode());
        contractsHistory.setDescription("编辑合同信息");
        contractsHistory.setBeforeContent(resultMap.get("before"));
        contractsHistory.setAfterContent(resultMap.get("after"));
        contractsHistory.setOperatorId(10000L);
        contractsHistory.setOperateDate(LocalDateTime.now());
        save(contractsHistory);
    }
}
